RootDialer

Struct RootDialer 

pub struct RootDialer { /* private fields */ }
RootDialer is the layer which enable communication between Roster shards.

It should know only his local slots and also the slots initiated by other CPU core locally. For every other slots, it should be delegated to the Cluster.

Should be cheap to clone

Implementations

Source

impl RootDialer

pub fn new(mesh: MeshBuilder<ConnectionMsg>, storage: &Storage) -> Self

pub fn part(&self, part: u16) -> Result<Dialer>

We return a Dialer specific to the part we use which knows to where it should communicate based on the hash key of other threads.