pub struct RootDialer { /* private fields */ }Expand description
RootDialer is the layer which enable communication between Roster shards.
It should know only his local slots and also the slots initiated by other CPU core locally. For every other slots, it should be delegated to the Cluster.
Should be cheap to clone
Implementations